==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/DataLegendSummaryEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSummaryEventArgsDescription } from "./DataLegendSummaryEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendSummaryEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSummaryEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSummaryEventArgsDescriptionMetadata.a == null) {
                DataLegendSummaryEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSummaryEventArgsDescriptionMetadata.c(DataLegendSummaryEventArgsDescriptionMetadata.a);
            }
            if (a.j(DataLegendSummaryEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnValues", "Array:double");
            a.item("ColumnMemberPath", "String");
            a.item("SummaryValue", "Number:double");
            a.item("SummaryUnits", "String");
            a.item("SummaryLabel", "String");
        }
        static d(a) {
            DataLegendSummaryEventArgsDescriptionMetadata.b(a);
            a.aa("DataLegendSummaryEventArgs", () => new DataLegendSummaryEventArgsDescription());
            a.z("DataLegendSummaryEventArgs", DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendSummaryEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataLegendSummaryEventArgsDescriptionMetadata, 'DataLegendSummaryEventArgsDescriptionMetadata');
    DataLegendSummaryEventArgsDescriptionMetadata.a = null;
    return DataLegendSummaryEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/DataLegendSummaryEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DataLegendSummaryEventArgsDescription } from "./DataLegendSummaryEventArgsDescription";
/**
 * @hidden
 */
export let DataLegendSummaryEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class DataLegendSummaryEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (DataLegendSummaryEventArgsDescriptionMetadata.a == null) {
                DataLegendSummaryEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                DataLegendSummaryEventArgsDescriptionMetadata.c(DataLegendSummaryEventArgsDescriptionMetadata.a);
            }
            if (a.k(DataLegendSummaryEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ColumnValues", "Array:double");
            a.item("ColumnMemberPath", "String");
            a.item("SummaryValue", "Number:double");
            a.item("SummaryUnits", "String");
            a.item("SummaryLabel", "String");
        }
        static d(a) {
            DataLegendSummaryEventArgsDescriptionMetadata.b(a);
            a.ac("DataLegendSummaryEventArgs", () => new DataLegendSummaryEventArgsDescription());
            a.ab("DataLegendSummaryEventArgs", DataLegendSummaryEventArgsDescriptionMetadata.a);
        }
    }
    DataLegendSummaryEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(DataLegendSummaryEventArgsDescriptionMetadata, 'DataLegendSummaryEventArgsDescriptionMetadata');
    DataLegendSummaryEventArgsDescriptionMetadata.a = null;
    return DataLegendSummaryEventArgsDescriptionMetadata;
})();
